function geodyn1(polelatdeg,polelongdeg,pointlatdeg,pointlongdeg,omegadegperMyr)
% Code to evaluate Equations (1-17)-(1-19)in Geodynamics. These formulas
% determine the relative velocity between plates at any point on the plate
% boundary, the angle delta subtended at the center of the Earth by the
% pole of rotation and point on the plate boundary, and the surface distance
% between the pole of rotation and the point.
%polelatdeg is the latitude of the pole in degrees in the range -90 deg to
%90 deg.
%polelongdeg is the longitude of the pole in degrees in the range -180 deg to
%180 deg. Positive eastward.
%pointlatdeg and pointlongdeg are similarly defined.
%omegadegperMyr is the rate of rotation of the pole in units of degrees per
%million years.
%units of surface distance is meters.
%delta is in radians.
%relativevel is in units of m/s.
polecolatrad=(90-polelatdeg)*pi/180;
polelongrad=polelongdeg*pi/180;
pointcolatrad=(90-pointlatdeg)*pi/180;
pointlongrad=pointlongdeg*pi/180;
delta=acos(cos(polecolatrad)*cos(pointcolatrad)+sin(polecolatrad)*sin(pointcolatrad)*cos(polelongrad-pointlongrad))
surfacedist=(6.3708*10^6)*delta
omegaradpersec=omegadegperMyr*(pi/180)/(1*10^6*3.1536*10^7);
relativevel=omegaradpersec*6.3708*10^6*sin(delta)
end
