function geodyn2dhc(Tsub0,delT,d,lambda,delta,N,M,niter)
%geodyn2dhc is a code to solve the two-dimensional, steady
%state heat conduction problem in a rectangular box of
%horizontal dimension lambda and vertical dimension d.
%The code solves for the temperature by using a finite
%difference approximation to Equation (4-51)
%subject to the boundary conditions of specified 
%temperature T at the top of the box, T given by
%Equation (11-25), and at the bottom of the box, T given
%by Equation (11-24). Zero heat flux boundary conditions
%are applied on the vertical sides of the box. 
%Tsub0 is the bottom temperature in units of K.
%delT is the amplitude of the periodic temperature
%variation at the top of the box in units of K.
%d is the height of the box in units of m.
%lambda is the width of the box in units of m.
%delta is the spacing of points in the layer (in m).
%Points are equally spaced in x and y.
%N is the number of horizontal points. There is an extra
%column of points to the left of the box and an extra
%column of points to the right of the box. These points
%are introduced in order to numerically apply the zero
%heat flux boundary conditions on the vertical sides of
%the box. N, delta, and lambda are related by
%(N-3)delta=lambda.
%M is the number of vertical points. M, delta, and d are
%related by (M-1)delta=d.
%niter is the number of times the code passes through the
% array of points in order to converge to the solution.
NM1=N-1;
for i=[2:1:NM1];
T(i,1)=Tsub0+delT*cos(2*pi*(i-2)*delta/lambda);
T(i,M)=Tsub0;
end
MM1=M-1;
for i=[2:1:NM1];
for j=[2:1:MM1];
T(i,j)=Tsub0;
end
end
NM2=N-2;
for j= [1:1:M];
T(1,j)=T(3,j);
T(N,j)=T(NM2,j);
end
for ij=[1:1:niter];
for i=[2:1:NM1];
for j=[2:1:MM1];
ip1=i+1;
im1=i-1;
jp1=j+1;
jm1=j-1;
T(i,j)=(T(ip1,j)+T(im1,j)+T(i,jp1)+T(i,jm1))/4;
end
end
for j=[1:1:M];
T(1,j)=T(3,j);
T(N,j)=T(NM2,j);
end
end
for i=[2:1:NM1]
    im2=i-2;
    T1(i)=T(i,1)-273;
    T2(i)=T(i,11)-273;
    x(i)=im2*delta;
end
plot (x,T1,'red');
hold on;
plot (x,T2,'green')









